@@ -5,10 +5,11 @@ Created on 29.01.2011
 @author: akvarats
 """
 
-from django.db import transaction
+from __future__ import absolute_import
 from django.dispatch import Signal
 
 from m3 import RelatedError
+from m3_django_compat import get_request_params, atomic
 from m3.actions import (
     ActionPack, Action, PreJsonResult, OperationResult, ACD, utils)
 from m3.actions.packs import ListDeleteRowAction
@@ -17,10 +18,9 @@ from m3.actions.interfaces import IMultiSelectablePack
 from m3_ext.ui.misc.store import ExtJsonStore
 from m3_ext.ui.windows.complex import ExtDictionaryWindow
 from m3_ext.ui.containers import ExtPagingBar
+from m3_ext.ui.results import ExtUIScriptResult
 from m3.db import BaseObjectModel, safe_delete
 
-class ExtUIScriptResult: pass
-
 
 class TreeGetNodesAction(Action):
     """
@@ -117,7 +117,7 @@ class ListGetRowsAction(Action):
         parent_id = utils.extract_int(request, 'id')
         offset = utils.extract_int(request, 'start')
         limit = utils.extract_int(request, 'limit')
-        filter = request.REQUEST.get('filter')
+        filter = get_request_params(request).get('filter')
         result = self.parent.get_rows(
             request, context, parent_id, offset, limit, filter)
         return PreJsonResult(result)
@@ -946,7 +946,7 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
         # Такая реализация обусловлена тем,
         # что IntegrityError невозможно отловить
         # до завершения транзакции, и приходится оборачивать транзакцию.
-        @transaction.commit_on_success
+        @atomic
         def delete_row_in_transaction(self, objs):
             message = ''
             if len(objs) == 0:
@@ -960,7 +960,7 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
                     ):
                         try:
                             obj.safe_delete()
-                        except RelatedError, e:
+                        except RelatedError as e:
                             message = e.args[0]
                     else:
                         if not safe_delete(obj):
@@ -973,7 +973,7 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
         # Тут пытаемся поймать ошибку из транзакции.
         try:
             return delete_row_in_transaction(self, objs)
-        except Exception, e:
+        except Exception as e:
             # Встроенный в Django IntegrityError не генерируется.
             # Кидаются исключения специфичные для каждого драйвера БД.
             # Но по спецификации PEP 249 все они называются IntegrityError
