@@ -1,24 +1,22 @@
-# coding: utf-8
+#coding: utf-8
 """
 Результаты выполнения экшенов
 +++++++++++++++++++++++++++++
 """
 
 from __future__ import absolute_import
-
-from copy import copy
-import abc
 import json
+import abc
+from copy import copy
 
 from django import http
 from django.conf import settings
-from six import iteritems
-from six import with_metaclass
 
 from .context import ActionContext
+import six
 
 
-class ActionResult(with_metaclass(abc.ABCMeta, object)):
+class ActionResult(six.with_metaclass(abc.ABCMeta, object)):
     """
     Класс описывает результат выполнения Action'а
     Данный класс является абстрактным.
@@ -89,6 +87,7 @@ class PreJsonResult(ActionResult):
         if settings.DEBUG:
             encoder.indent = 4
             encoder.separators = (',', ': ')
+            encoder.sort_keys = True
 
         result = encoder.encode(self.data)
         response = http.HttpResponse(result, content_type='application/json')
@@ -139,9 +138,9 @@ class XMLResult(ActionResult):
         )
 
 
-# =============================================================================
+#==============================================================================
 # Результаты выполнения операции с заданным контекстом
-# =============================================================================
+#==============================================================================
 class BaseContextedResult(ActionResult):
     """
     Абстрактный базовый класс, который оперирует понятием результата
@@ -251,8 +250,7 @@ class ActionRedirectResult(object):
     def prepare_request(self, request):
         if self.context:
             new_post = copy(request.POST)
-            for k, v in iteritems(new_post.__dict__):
+            for k, v in six.iteritems(new_post.__dict__):
                 new_post[k] = getattr(self.context, k, v)
             request.POST = new_post
-            del request._request
         return request
